@@ -2,6 +2,7 @@ import datetime
 import json
 import logging
 
+from django.core.files.base import ContentFile
 from django.db import IntegrityError, transaction
 from django.db.models import Q
 
@@ -33,16 +34,18 @@ class DatabaseJobSource(object):
             if device.status != Device.IDLE:
                 return None
             jobs_for_device = TestJob.objects.all().filter(
-                Q(target=device) | Q(device_type=device.device_type),
+                Q(requested_device=device)
+                | Q(requested_device_type=device.device_type),
                 status=TestJob.SUBMITTED)
             jobs_for_device = jobs_for_device.extra(
-                select={'is_targeted': 'target_id is not NULL'},
+                select={'is_targeted': 'requested_device_id is not NULL'},
                 order_by=['-is_targeted', 'submit_time'])
             jobs = jobs_for_device[:1]
             if jobs:
                 job = jobs[0]
                 job.status = TestJob.RUNNING
                 job.start_time = datetime.datetime.utcnow()
+                job.actual_device = device
                 device.status = Device.RUNNING
                 device.current_job = job
                 try:
@@ -56,9 +59,15 @@ class DatabaseJobSource(object):
                     transaction.rollback()
                     continue
                 else:
+                    job.log_file.save(
+                        'job-%s.log' % job.id, ContentFile(''), save=False)
                     job.save()
                     transaction.commit()
-                    return json.loads(job.definition)
+                    json_data = json.loads(job.definition)
+                    log_file = job.log_file
+                    log_file.file.close()
+                    log_file.open('wb')
+                    return json_data, log_file
             else:
                 # We don't really need to rollback here, as no modifying
                 # operations have been made to the database.  But Django is
@@ -72,17 +81,16 @@ class DatabaseJobSource(object):
         return deferToThread(self.getJobForBoard_impl, board_name)
 
     @transaction.commit_on_success()
-    def jobCompleted_impl(self, board_name, log_stream):
+    def jobCompleted_impl(self, board_name):
         self.logger.debug('marking job as complete on %s', board_name)
         device = Device.objects.get(hostname=board_name)
         device.status = Device.IDLE
+        job = device.current_job
         device.current_job = None
-        job = TestJob.objects.get(target=device, status=TestJob.RUNNING)
         job.status = TestJob.COMPLETE
         job.end_time = datetime.datetime.utcnow()
         device.save()
         job.save()
 
-    def jobCompleted(self, board_name, log_file_path):
-        return deferToThread(
-            self.jobCompleted_impl, board_name, log_file_path)
+    def jobCompleted(self, board_name):
+        return deferToThread(self.jobCompleted_impl, board_name)
